## Aliyun ROS MARKETPLACE Construct Library

This module is part of the AliCloud ROS Cloud Development Kit (ROS CDK) project.

```python
import * as MARKETPLACE from '@alicloud/ros-cdk-marketplace';
```
